@@ -25,20 +25,19 @@ class RecognizeIdentityCardRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'ocr', '2019-12-30', 'RecognizeIdentityCard','ocr')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Side(self):
+	def get_Side(self): # String
 		return self.get_body_params().get('Side')
 
-	def set_Side(self,Side):
+	def set_Side(self, Side):  # String
 		self.add_body_params('Side', Side)
-
-	def get_ImageURL(self):
+	def get_ImageURL(self): # String
 		return self.get_body_params().get('ImageURL')
 
-	def set_ImageURL(self,ImageURL):
-		self.add_body_params('ImageURL', ImageURL)
\ No newline at end of file
+	def set_ImageURL(self, ImageURL):  # String
+		self.add_body_params('ImageURL', ImageURL)
